<?php
/*
Plugin Name: Exclude Category Plugin
Plugin URI: http://www.simplecoding.org/plagin-wordpress-isklyuchaem-nenuzhnye-kategorii.html
Description: Позволяет убрать посты указанных категорий с главной страницы и из RSS ленты.
Version: 1.1
Author: Statsenko Vladimir
Author URI: http://www.simplecoding.org
*/

//-----------------------------------------
//создаём подменю Settings->Exclude Category Plugin и соответствующую форму

//регистрируем функцию создания меню
add_action('admin_menu', 'ec_create_menu');

//функция создания меню
function ec_create_menu() {
    add_submenu_page('options-general.php'
                     ,'Exclude Category Plugin Settings'
                     , 'Exclude Category'
                     , 'edit_plugins'
                     , __FILE__
                     , 'ec_settings_page');
    
    //Регистрируем функцию register_ec_settings. Она нужна для автоматической
    //обработки формы с настройками
    add_action( 'admin_init', 'register_ec_settings' );
}

/**
 * Функция регистрирует группы полей с настройками.
 * В данном случае, это массивы чекбоксов.
 * После регистрации обработка данных формы выполняется автоматически,
 * т.е. WP сам создаёт и обновляет опции в БД (при этом выполняется сериализация
 * данных).
 * Подробнее здесь http://codex.wordpress.org/Creating_Options_Pages
 */
function register_ec_settings() {
	register_setting( 'ec-settings-group', 'cats_list' );
	register_setting( 'ec-settings-group', 'cats_home' );
}

function ec_settings_page() {
    //получаем список категорий
    $categories = get_categories(array('hide_empty' => false));
?>
<div class="wrap">
    <h2>Exclude Category Plugin Settings</h2>
    <form method="post" action="options.php">
        <?php
            //Необходимо для автоматической обработки формы
            settings_fields( 'ec-settings-group' );
        ?>
        <table class="form-table">
            <tbody>
                <tr valign="top">
                    <th scope="row">Выберите категории, которые нужно исключить</th>
                    <td>
                        <fieldset>
                            <legend class="screen-reader-text"><span>Выберите категории, которые нужно исключить</span></legend>
                        <?php
                            //читаем значение текущее опции
                            $curCL = get_option('cats_list');
                            foreach ($categories as $category) {
                                $checked = '';
                                if (is_array($curCL) && in_array($category->cat_ID, $curCL)) {
                                    $checked = 'checked="checked"';
                                }
                                echo '<label><input '.$checked.' type="checkbox" name="cats_list[]" value="'.$category->cat_ID.'" /> '.$category->name.'</label><br />';
                            }
                        ?>
                        </fieldset>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Не выводить выбранные категории</th>
                    <td>
                        <fieldset>
                            <legend class="screen-reader-text"><span>Не выводить выбранные категории</span></legend>
                            <?php
                                $curCH = get_option('cats_home');
                                $cH = $cF = '';
                                if (is_array($curCH)) {
                                    $cH = in_array('home', $curCH) ? 'checked="checked"' : '';
                                    $cF = in_array('feed', $curCH) ? 'checked="checked"' : '';
                                }
                            ?>
                            <label><input type="checkbox" <?php echo $cH; ?> name="cats_home[]" value="home" /> на главной</label><br />
                            <label><input type="checkbox" <?php echo $cF; ?> name="cats_home[]" value="feed" /> в RSS ленте</label>
                        </fieldset>
                    </td>
                </tr>
            </tbody>
        </table>
        <p class="submit"><input type="submit" class="button-primary" value="Сохранить" /></p>
    </form>
</div>

<?php
}
//-----------------------------------------
//удаляем записи соответствующих категорий

add_filter('pre_get_posts','ec_exclude');

/**
 * Функция проверяет опции и исключает посты, которые относятся к указанным
 * категориям из общего списка.
 */
function ec_exclude($query) {
    if (!is_front_page()) {
        return $query;
    }
    //читаем массивы с опциями
    if (is_array($target = get_option('cats_home'))) {
        if (is_array($categories = get_option('cats_list'))) {
            //формируем строку с перечнем категорий
            $cat_string = implode(',', $categories);
            //удаляем посты указанных категорий из RSS ленты
            if (in_array('feed', $target) && $query->is_feed) {
                $query->set('category__not_in',$categories);
            }
            //удаляем посты указанных категорий с главной страницы
            if (in_array('home', $target) && $query->is_home) {
                $query->set('category__not_in',$categories);
            }
        }
    }
    return $query;
}
// end of exclude_category.php